/* main.c generated by valac 0.38.4, the Vala compiler
 * generated from main.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <glib/gi18n-lib.h>
#include <stdio.h>
#include <config.h>
#include <stdlib.h>
#include <gio/gio.h>
#include <string.h>
#include <libcommon.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <gtk/gtk.h>

#define _g_option_context_free0(var) ((var == NULL) ? NULL : (var = (g_option_context_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block61Data Block61Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _RunChecksData RunChecksData;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _Block61Data {
	int _ref_count_;
	GMainLoop* loop;
};

struct _RunChecksData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gchar* selinux_context_diagnosis;
	gchar* _tmp0_;
	gchar* storage_pool_diagnosis;
	gchar* _tmp1_;
	gboolean cpu;
	gboolean _tmp2_;
	gboolean kvm;
	gboolean _tmp3_;
	gboolean libvirt_kvm;
	gboolean _tmp4_;
	gboolean selinux_context_default;
	gchar* _tmp5_;
	gboolean _tmp6_;
	gboolean storage_pool;
	gchar* _tmp7_;
	gboolean _tmp8_;
	FILE* _tmp9_;
	gboolean _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	FILE* _tmp15_;
	gboolean _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	FILE* _tmp21_;
	gboolean _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	FILE* _tmp27_;
	gboolean _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	const gchar* _tmp33_;
	gint _tmp34_;
	gint _tmp35_;
	FILE* _tmp36_;
	const gchar* _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	FILE* _tmp42_;
	gboolean _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gchar* _tmp47_;
	const gchar* _tmp48_;
	gint _tmp49_;
	gint _tmp50_;
	FILE* _tmp51_;
	const gchar* _tmp52_;
	gchar* _tmp53_;
	gchar* _tmp54_;
	gchar* _tmp55_;
	gchar* _tmp56_;
	FILE* _tmp57_;
	FILE* _tmp58_;
	FILE* _tmp59_;
	const gchar* _tmp60_;
};


extern gboolean version;
gboolean version = FALSE;
extern gboolean checks;
gboolean checks = FALSE;

void parse_local_args (gchar*** args, int* args_length1);
static Block61Data* block61_data_ref (Block61Data* _data61_);
static void block61_data_unref (void * _userdata_);
void run_checks (GAsyncReadyCallback _callback_, gpointer _user_data_);
void run_checks_finish (GAsyncResult* _res_);
static void ___lambda264_ (Block61Data* _data61_, GObject* obj, GAsyncResult* res);
static void ____lambda264__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void run_checks_data_free (gpointer _data);
static gboolean run_checks_co (RunChecksData* _data_);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
static void run_checks_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_);
void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar* * diagnosis);
void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar* * diagnosis);
gint _vala_main (gchar** args, int args_length1);
GType boxes_app_get_type (void) G_GNUC_CONST;
BoxesApp* boxes_app_new (void);
BoxesApp* boxes_app_construct (GType object_type);

const GOptionEntry local_options[3] = {{"version", (gchar) 0, 0, G_OPTION_ARG_NONE, &version, N_ ("Display version number"), NULL}, {"checks", (gchar) 0, 0, G_OPTION_ARG_NONE, &checks, N_ ("Check virtualization capabilities"), NULL}, {NULL}};

static Block61Data* block61_data_ref (Block61Data* _data61_) {
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	g_atomic_int_inc (&_data61_->_ref_count_);
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	return _data61_;
#line 155 "main.c"
}


static void block61_data_unref (void * _userdata_) {
	Block61Data* _data61_;
	_data61_ = (Block61Data*) _userdata_;
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	if (g_atomic_int_dec_and_test (&_data61_->_ref_count_)) {
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_g_main_loop_unref0 (_data61_->loop);
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		g_slice_free (Block61Data, _data61_);
#line 168 "main.c"
	}
}


static void ___lambda264_ (Block61Data* _data61_, GObject* obj, GAsyncResult* res) {
	GAsyncResult* _tmp0_;
	GMainLoop* _tmp1_;
#line 32 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	g_return_if_fail (res != NULL);
#line 33 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_tmp0_ = res;
#line 33 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	run_checks_finish (_tmp0_);
#line 34 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_tmp1_ = _data61_->loop;
#line 34 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	g_main_loop_quit (_tmp1_);
#line 186 "main.c"
}


static void ____lambda264__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 32 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	___lambda264_ (self, source_object, res);
#line 32 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	block61_data_unref (self);
#line 195 "main.c"
}


void parse_local_args (gchar*** args, int* args_length1) {
	GOptionContext* opt_context = NULL;
	GOptionContext* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp3_;
	GError * _inner_error_ = NULL;
#line 15 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_tmp0_ = g_option_context_new (NULL);
#line 15 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	opt_context = _tmp0_;
#line 16 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	g_option_context_set_ignore_unknown_options (opt_context, TRUE);
#line 17 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	g_option_context_add_main_entries (opt_context, local_options, NULL);
#line 18 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	g_option_context_set_help_enabled (opt_context, FALSE);
#line 215 "main.c"
	{
#line 21 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		g_option_context_parse (opt_context, args_length1, args, &_inner_error_);
#line 21 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 21 "/home/fborges/checkout/gnome-boxes/src/main.vala"
			if (_inner_error_->domain == G_OPTION_ERROR) {
#line 223 "main.c"
				goto __catch62_g_option_error;
			}
#line 21 "/home/fborges/checkout/gnome-boxes/src/main.vala"
			_g_option_context_free0 (opt_context);
#line 21 "/home/fborges/checkout/gnome-boxes/src/main.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 21 "/home/fborges/checkout/gnome-boxes/src/main.vala"
			g_clear_error (&_inner_error_);
#line 21 "/home/fborges/checkout/gnome-boxes/src/main.vala"
			return;
#line 234 "main.c"
		}
	}
	goto __finally62;
	__catch62_g_option_error:
	{
		GError* _error_ = NULL;
#line 20 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_error_ = _inner_error_;
#line 20 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_inner_error_ = NULL;
#line 20 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_g_error_free0 (_error_);
#line 247 "main.c"
	}
	__finally62:
#line 20 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_g_option_context_free0 (opt_context);
#line 20 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 20 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		g_clear_error (&_inner_error_);
#line 20 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		return;
#line 260 "main.c"
	}
#line 25 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_tmp1_ = version;
#line 25 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	if (_tmp1_) {
#line 266 "main.c"
		FILE* _tmp2_;
#line 26 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_tmp2_ = stdout;
#line 26 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		fprintf (_tmp2_, "%s\n", PACKAGE_VERSION);
#line 27 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		exit (0);
#line 274 "main.c"
	}
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_tmp3_ = checks;
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	if (_tmp3_) {
#line 280 "main.c"
		Block61Data* _data61_;
		GMainLoop* _tmp4_;
		GMainLoop* _tmp5_;
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data61_ = g_slice_new0 (Block61Data);
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data61_->_ref_count_ = 1;
#line 31 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_tmp4_ = g_main_loop_new (NULL, FALSE);
#line 31 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data61_->loop = _tmp4_;
#line 32 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		run_checks (____lambda264__gasync_ready_callback, block61_data_ref (_data61_));
#line 36 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_tmp5_ = _data61_->loop;
#line 36 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		g_main_loop_run (_tmp5_);
#line 37 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		exit (0);
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		block61_data_unref (_data61_);
#line 30 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data61_ = NULL;
#line 304 "main.c"
	}
#line 14 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_option_context_free0 (opt_context);
#line 308 "main.c"
}


static void run_checks_data_free (gpointer _data) {
	RunChecksData* _data_;
	_data_ = _data;
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (RunChecksData, _data_);
#line 317 "main.c"
}


void run_checks (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	RunChecksData* _data_;
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (RunChecksData);
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_task_new (NULL, NULL, _callback_, _user_data_);
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	g_task_set_task_data (_data_->_async_result, _data_, run_checks_data_free);
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	run_checks_co (_data_);
#line 331 "main.c"
}


void run_checks_finish (GAsyncResult* _res_) {
	RunChecksData* _data_;
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 339 "main.c"
}


static void run_checks_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	RunChecksData* _data_;
#line 46 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_ = _user_data_;
#line 46 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_source_object_ = source_object;
#line 46 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_res_ = _res_;
#line 46 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	run_checks_co (_data_);
#line 353 "main.c"
}


static gboolean run_checks_co (RunChecksData* _data_) {
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	switch (_data_->_state_) {
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		case 0:
#line 362 "main.c"
		goto _state_0;
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		case 1:
#line 366 "main.c"
		goto _state_1;
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		case 2:
#line 370 "main.c"
		goto _state_2;
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		case 3:
#line 374 "main.c"
		goto _state_3;
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		case 4:
#line 378 "main.c"
		goto _state_4;
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		case 5:
#line 382 "main.c"
		goto _state_5;
		default:
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		g_assert_not_reached ();
#line 387 "main.c"
	}
	_state_0:
#line 42 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 42 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->selinux_context_diagnosis = _data_->_tmp0_;
#line 43 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp1_ = g_strdup ("");
#line 43 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->storage_pool_diagnosis = _data_->_tmp1_;
#line 46 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_state_ = 1;
#line 46 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	boxes_check_cpu_vt_capability (run_checks_ready, _data_);
#line 46 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	return FALSE;
#line 404 "main.c"
	_state_1:
#line 46 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp2_ = boxes_check_cpu_vt_capability_finish (_data_->_res_);
#line 46 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->cpu = _data_->_tmp2_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_state_ = 2;
#line 47 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	boxes_check_module_kvm_loaded (run_checks_ready, _data_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	return FALSE;
#line 416 "main.c"
	_state_2:
#line 47 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp3_ = boxes_check_module_kvm_loaded_finish (_data_->_res_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->kvm = _data_->_tmp3_;
#line 48 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_state_ = 3;
#line 48 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	boxes_check_libvirt_kvm (run_checks_ready, _data_);
#line 48 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	return FALSE;
#line 428 "main.c"
	_state_3:
#line 48 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp4_ = boxes_check_libvirt_kvm_finish (_data_->_res_);
#line 48 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->libvirt_kvm = _data_->_tmp4_;
#line 49 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp5_ = NULL;
#line 49 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_state_ = 4;
#line 49 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	boxes_check_selinux_context_default (run_checks_ready, _data_);
#line 49 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	return FALSE;
#line 442 "main.c"
	_state_4:
#line 49 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp6_ = boxes_check_selinux_context_default_finish (_data_->_res_, &_data_->_tmp5_);
#line 49 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->selinux_context_diagnosis);
#line 49 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->selinux_context_diagnosis = _data_->_tmp5_;
#line 49 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->selinux_context_default = _data_->_tmp6_;
#line 50 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp7_ = NULL;
#line 50 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_state_ = 5;
#line 50 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	boxes_check_storage_pool (run_checks_ready, _data_);
#line 50 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	return FALSE;
#line 460 "main.c"
	_state_5:
#line 50 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp8_ = boxes_check_storage_pool_finish (_data_->_res_, &_data_->_tmp7_);
#line 50 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->storage_pool_diagnosis);
#line 50 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->storage_pool_diagnosis = _data_->_tmp7_;
#line 50 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->storage_pool = _data_->_tmp8_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp9_ = stdout;
#line 53 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp10_ = _data_->cpu;
#line 53 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp11_ = boxes_yes_no (_data_->_tmp10_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp13_ = g_strdup_printf (_ ("• The CPU is capable of virtualization: %s\n"), _data_->_tmp12_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp14_ = _data_->_tmp13_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp9_, "%s", _data_->_tmp14_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp14_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp12_);
#line 54 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp15_ = stdout;
#line 54 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp16_ = _data_->kvm;
#line 54 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp17_ = boxes_yes_no (_data_->_tmp16_);
#line 54 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 54 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp19_ = g_strdup_printf (_ ("• The KVM module is loaded: %s\n"), _data_->_tmp18_);
#line 54 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp20_ = _data_->_tmp19_;
#line 54 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp15_, "%s", _data_->_tmp20_);
#line 54 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp20_);
#line 54 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp18_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp21_ = stdout;
#line 55 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp22_ = _data_->libvirt_kvm;
#line 55 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp23_ = boxes_yes_no (_data_->_tmp22_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp24_ = _data_->_tmp23_;
#line 55 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp25_ = g_strdup_printf (_ ("• Libvirt KVM guest available: %s\n"), _data_->_tmp24_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 55 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp21_, "%s", _data_->_tmp26_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp26_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp24_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp27_ = stdout;
#line 56 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp28_ = _data_->storage_pool;
#line 56 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp29_ = boxes_yes_no (_data_->_tmp28_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp30_ = _data_->_tmp29_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp31_ = g_strdup_printf (_ ("• Boxes storage pool available: %s\n"), _data_->_tmp30_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp32_ = _data_->_tmp31_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp27_, "%s", _data_->_tmp32_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp32_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp30_);
#line 57 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp33_ = _data_->storage_pool_diagnosis;
#line 57 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp34_ = strlen (_data_->_tmp33_);
#line 57 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp35_ = _data_->_tmp34_;
#line 57 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	if (_data_->_tmp35_ != 0) {
#line 58 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp36_ = stdout;
#line 58 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp37_ = _data_->storage_pool_diagnosis;
#line 58 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp38_ = boxes_indent ("    ", _data_->_tmp37_);
#line 58 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp39_ = _data_->_tmp38_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp40_ = g_strconcat (_data_->_tmp39_, "\n", NULL);
#line 58 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp41_ = _data_->_tmp40_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		fprintf (_data_->_tmp36_, "%s", _data_->_tmp41_);
#line 58 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_g_free0 (_data_->_tmp41_);
#line 58 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_g_free0 (_data_->_tmp39_);
#line 568 "main.c"
	}
#line 60 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp42_ = stdout;
#line 60 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp43_ = _data_->selinux_context_default;
#line 60 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp44_ = boxes_yes_no (_data_->_tmp43_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp45_ = _data_->_tmp44_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp46_ = g_strdup_printf (_ ("• The SELinux context is default: %s\n"), _data_->_tmp45_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp47_ = _data_->_tmp46_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp42_, "%s", _data_->_tmp47_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp47_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->_tmp45_);
#line 61 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp48_ = _data_->selinux_context_diagnosis;
#line 61 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp49_ = strlen (_data_->_tmp48_);
#line 61 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp50_ = _data_->_tmp49_;
#line 61 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	if (_data_->_tmp50_ != 0) {
#line 62 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp51_ = stdout;
#line 62 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp52_ = _data_->selinux_context_diagnosis;
#line 62 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp53_ = boxes_indent ("    ", _data_->_tmp52_);
#line 62 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp54_ = _data_->_tmp53_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp55_ = g_strconcat (_data_->_tmp54_, "\n", NULL);
#line 62 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_data_->_tmp56_ = _data_->_tmp55_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		fprintf (_data_->_tmp51_, "%s", _data_->_tmp56_);
#line 62 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_g_free0 (_data_->_tmp56_);
#line 62 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_g_free0 (_data_->_tmp54_);
#line 614 "main.c"
	}
#line 63 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp57_ = stdout;
#line 63 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp57_, "\n");
#line 64 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp58_ = stdout;
#line 64 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp58_, _ ("Report bugs to <%s>.\n"), PACKAGE_BUGREPORT);
#line 65 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp59_ = stdout;
#line 65 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_data_->_tmp60_ = g_get_application_name ();
#line 65 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	fprintf (_data_->_tmp59_, _ ("%s home page: <%s>.\n"), _data_->_tmp60_, PACKAGE_URL);
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->storage_pool_diagnosis);
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_free0 (_data_->selinux_context_diagnosis);
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	if (_data_->_state_ != 0) {
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 642 "main.c"
		}
	}
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	g_object_unref (_data_->_async_result);
#line 41 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	return FALSE;
#line 649 "main.c"
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	BoxesApp* app = NULL;
	BoxesApp* _tmp2_;
	gint exit_status = 0;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gint _tmp4_;
	GError * _inner_error_ = NULL;
#line 69 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
#line 70 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
#line 71 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	textdomain (GETTEXT_PACKAGE);
#line 72 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	g_set_application_name (_ ("Boxes"));
#line 74 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	parse_local_args (&args, &args_length1);
#line 672 "main.c"
	{
#line 77 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		gvir_init_object_check (&args_length1, &args, &_inner_error_);
#line 77 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 678 "main.c"
			goto __catch63_g_error;
		}
	}
	goto __finally63;
	__catch63_g_error:
	{
		GError* err = NULL;
		const gchar* _tmp0_;
#line 76 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		err = _inner_error_;
#line 76 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_inner_error_ = NULL;
#line 79 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_tmp0_ = err->message;
#line 79 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		g_error ("main.vala:79: %s", _tmp0_);
#line 76 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		_g_error_free0 (err);
#line 697 "main.c"
	}
	__finally63:
#line 76 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 702 "main.c"
		gint _tmp1_ = 0;
#line 76 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 76 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		g_clear_error (&_inner_error_);
#line 76 "/home/fborges/checkout/gnome-boxes/src/main.vala"
		return _tmp1_;
#line 710 "main.c"
	}
#line 82 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_tmp2_ = boxes_app_new ();
#line 82 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	app = _tmp2_;
#line 84 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_tmp3_ = args;
#line 84 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_tmp3__length1 = args_length1;
#line 84 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_tmp4_ = g_application_run ((GApplication*) app, _tmp3__length1, _tmp3_);
#line 84 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	exit_status = _tmp4_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	result = exit_status;
#line 86 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	_g_object_unref0 (app);
#line 86 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	return result;
#line 730 "main.c"
}


int main (int argc, char ** argv) {
#line 68 "/home/fborges/checkout/gnome-boxes/src/main.vala"
	return _vala_main (argv, argc);
#line 737 "main.c"
}



